@@ -1,7 +1,7 @@
 """enums to be used by consumers of the Marqo client"""
+from enum import Enum
 
-
-class SearchMethods:
+class SearchMethods(str, Enum):
     LEXICAL = "LEXICAL"
     TENSOR = "TENSOR"
 
